Module blaxel.core.client.models.check_workspace_availability_body
==================================================================

Classes
-------

`CheckWorkspaceAvailabilityBody(name: str)`
:   Attributes:
        name (str):
    
    Method generated by attrs for class CheckWorkspaceAvailabilityBody.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `name: str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :